"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const identifyEnvironment_1 = require("./identifyEnvironment");
const getLogLevelFromEnvVar = () => {
    // grab the log level env var
    const logLevelEnvVar = process.env.LOG_LEVEL || null; // cast falsy values to null
    // if log level wasn't defined, null
    if (!logLevelEnvVar)
        return null;
    // if log level wasn't defined w/ a valid value, warn and null
    if (!constants_1.isOfLogLevel(logLevelEnvVar)) {
        // tslint:disable-next-line: no-console
        console.warn(`environmental variable LOG_LEVEL was set to an invalid value: '${logLevelEnvVar}'. using the default instead`);
        return null;
    }
    // if it was valid, then return it
    return logLevelEnvVar;
};
exports.getRecommendedMinimalLogLevelForEnvironment = () => {
    // if the LOG_LEVEL env var is defined, then use what is specified by that
    const logLevelFromEnvVar = getLogLevelFromEnvVar();
    if (logLevelFromEnvVar)
        return logLevelFromEnvVar;
    // identify the env we're in
    const env = identifyEnvironment_1.identifyEnvironment();
    // if we're in aws lambda env, then default to DEBUG - since cloudwatch costs are cheap and extra visibility is worth it in most cases
    if (env === constants_1.SupportedEnvironment.AWS_LAMBDA)
        return constants_1.LogLevel.DEBUG;
    // otherwise, default to INFO - to balance signal -vs- noise
    return constants_1.LogLevel.INFO;
};
//# sourceMappingURL=getRecommendedMinimalLogLevelForEnvironment.js.map